@@ -2,7 +2,7 @@
 
 """mesh_sync provides entry point main()."""
 
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 
 import base64
 import re
@@ -159,15 +159,7 @@ def get_all_files(auth_token: str, repo_url):
 
 def main():
     try:
-        # Check if config.txt exists
-        if not os.path.exists('config.txt'):
-            token = input("Token not found, please enter your github token: ")
-            with open('config.txt', 'w') as f:
-                f.write(token)
-        else:
-            # read the token from config.txt
-            with open('config.txt', 'r') as f:
-                token = f.read()
+        token = input("Enter your GitHub token: ")
 
         print(">> Executing mesh_sync version %s." % __version__)
         if check_if_dot_git_exists():
@@ -193,3 +185,5 @@ def main():
     except Exception as e:
         print("Error: %s" % e)
         sys.exit(0)
+    finally:
+        print(">> Done.")
